StartLineError

Enum StartLineError 

#[non_exhaustive]
pub enum StartLineError { Empty, RequestLineShape, Method, Uri(UriError), MissingStatusCode, StatusCode, }
What was wrong with a start line.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Empty

The message is empty, or the start line is.



RequestLineShape

A request line did not have exactly three space-separated elements. Covers multiple spaces between elements and a trailing space (RFC 4475 3.1.2.9, 3.1.2.10).



Method

The method is not a token.



Uri(UriError)

The Request-URI did not parse — including when it is wrapped in <> (RFC 4475 3.1.2.7) or contains whitespace (3.1.2.8).



MissingStatusCode

A status line had no status code.



StatusCode

The status code is not exactly three digits in 100..=699 (RFC 4475 3.1.2.19).