#[non_exhaustive]pub enum WarningEditError {
Malformed(HeaderError),
IndexOutOfRange {
index: usize,
},
InvalidPseudonym,
}Expand description
Why a parser-owned Warning agent could not be edited losslessly.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Malformed(HeaderError)
At least one row did not match the complete Warning field grammar.
IndexOutOfRange
The flattened, zero-based Warning value index does not exist.
InvalidPseudonym
The replacement is empty or is not one RFC 3261 token.