#[non_exhaustive]pub enum AddressEditError {
UnsupportedHeader,
Malformed(HeaderError),
IndexOutOfRange {
index: usize,
},
InvalidUri(UriError),
InvalidDisplayName,
}Expand description
Why a parser-owned address value could not be edited losslessly.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedHeader
The field does not use one of the address grammars exposed by this operation.
Malformed(HeaderError)
At least one row did not match the field’s shared address grammar.
IndexOutOfRange
The flattened, zero-based value index does not exist.
InvalidUri(UriError)
The replacement URI did not survive serialization as a valid URI.
InvalidDisplayName
A replacement display name contains a header-delimiting control byte.