pub enum PrivacyValue {
User,
Header,
Session,
None,
Critical,
Id,
History,
Extension(Vec<u8>),
}Expand description
One value from a Privacy header.
The first seven variants are the values in the IANA SIP Privacy Header Field Values registry.
Extension retains the spelling of a later token so policy can recognize it without waiting
for this enum to gain another variant.
Variants
User
Request user-level privacy.
Header
Request privacy for identifying routing headers.
Session
Request privacy for session media.
None
Explicitly request no privacy service.
Critical
Require requested privacy services to succeed or the request to fail.
Id
Request privacy for asserted identity (RFC 3325 9.3).
History
Request privacy for History-Info (RFC 7044 10.1).
Extension(Vec<u8>)
A later registered token, preserving its spelling.
Implementations