pub enum ServerState {
Trying,
Proceeding,
Completed,
Confirmed,
Accepted,
Terminated,
}Expand description
The state of a server transaction.
Variants
Trying
Non-INVITE: the request is with the transaction user and nothing has been sent.
Proceeding
A provisional response has been sent, or an INVITE is being processed.
Completed
A final response has been sent; waiting out request retransmissions, or an ACK.
Confirmed
INVITE: the ACK arrived; waiting out its retransmissions.
Accepted
RFC 6026: a 2xx was sent and the ACK belongs to the transaction user.
Terminated
Over.
Implementations
Sourceimpl ServerState
impl ServerState
Sourcepub fn is_terminated(self) -> bool
pub fn is_terminated(self) -> bool
Whether the transaction has finished and can be dropped.